summaryrefslogtreecommitdiffstats
path: root/src/freshklam.h
diff options
context:
space:
mode:
authorMavridis Philippe <mavridisf@gmail.com>2021-01-13 19:34:09 +0200
committerMavridis Philippe <mavridisf@gmail.com>2021-01-13 19:34:09 +0200
commit4c04a441814c7d1dda08f6075ab4e09dc05541df (patch)
treecf8a3dbd77114c416255d3995cd1b047072ef26a /src/freshklam.h
parent357ddeb8afd82d69ef871c146f4fc8f2c67fb17e (diff)
downloadklamav-4c04a441814c7d1dda08f6075ab4e09dc05541df.tar.gz
klamav-4c04a441814c7d1dda08f6075ab4e09dc05541df.zip
Conversion KDE3->TDE
Signed-off-by: Mavridis Philippe <mavridisf@gmail.com>
Diffstat (limited to 'src/freshklam.h')
-rw-r--r--src/freshklam.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/freshklam.h b/src/freshklam.h
index 96e1f99..f6a4bf9 100644
--- a/src/freshklam.h
+++ b/src/freshklam.h
@@ -9,12 +9,12 @@
#include <config.h>
#endif
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
#include <kdirlister.h> //stack allocated
#include <kurl.h> //stack allocated
#include <kresolver.h> // namespace
-#include <khtml_part.h>
+#include <tdehtml_part.h>
#include "update.h"
namespace DOM {
@@ -25,7 +25,7 @@ namespace DOM {
using namespace KNetwork;
class KPrinter;
-class KToggleAction;
+class TDEToggleAction;
class KURL;
class TQLineEdit;
class TQComboBox;
@@ -33,13 +33,13 @@ class TQCheckBox;
class TQListBox;
class TQPushButton;
class TQLabel;
-class KProcess;
-class KConfig;
+class TDEProcess;
+class TDEConfig;
class KURLRequester;
class KLineEdit;
class KProgressDialog;
class KProcIO;
-class KHTMLPart;
+class TDEHTMLPart;
class KlamavUpdate;
/**
@@ -85,14 +85,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- //void saveProperties(KConfig *);
+ //void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- //void readProperties(KConfig *);
+ //void readProperties(TDEConfig *);
@@ -119,13 +119,13 @@ private slots:
/* void slotProg();*/
void childExited();
void processDied();
- void receivedOutput(KProcess *proc, char *buffer, int buflen);
+ void receivedOutput(TDEProcess *proc, char *buffer, int buflen);
void slotClear();
void writeConf();
void handleChecks();
- //void arkollonExited(KProcess *arkollonproc);
-/* void klamavInstallationExited(KProcess *arkollonproc);
- void clamavInstallationExited(KProcess *arkollonproc);*/
+ //void arkollonExited(TDEProcess *arkollonproc);
+/* void klamavInstallationExited(TDEProcess *arkollonproc);
+ void clamavInstallationExited(TDEProcess *arkollonproc);*/
//void newItems( const KFileItemList& );
void resolved(KResolverResults result);
void checkForNewKlamAVNow();
@@ -165,10 +165,10 @@ private:
TQCheckBox *recursive_box;
TQListBox *resultbox;
TQLabel *status_label, *matches_label;
- KProcess *childproc;
+ TDEProcess *childproc;
KProcIO *versionproc;
TQString buf;
- KConfig* config;
+ TDEConfig* config;
TQStringList lastSearchItems;
TQStringList lastDownloadPaths;
KLineEdit *proxyIP;
@@ -188,7 +188,7 @@ private:
TQString highestsofarfilename;*/
KResolver m_resolver;
/* TQString currentClamAVVersion;
- KHTMLPart *filelist;*/
+ TDEHTMLPart *filelist;*/
TQPushButton *clamav_options;
TQPushButton *klamav_options;
@@ -85,14 +85,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties